@@ -23,12 +23,11 @@
 u_long id = 1330135598;
 u_long options = BEQ_THREAD;
 
-#define INSIZE 256
-
 /* JACK data */
 static jack_port_t **input_ports;
 static jack_client_t *client;
 static char *source_names[2] = { NULL, NULL };
+static const char **ports;
 
 
 static void
@@ -42,12 +41,16 @@ jack_shutdown(void *arg)
 static int
 process(jack_nframes_t nframes, void *arg)
 {
-  unsigned int chn;
-  size_t i;
+  int chn;
+  uint32_t i;
   Context_t *ctx = (Context_t *)arg;
   jack_default_audio_sample_t *in;
 
-  nframes = (nframes > INSIZE) ? INSIZE : nframes;
+  if (nframes > ctx->input->size) {
+    VERBOSE(printf("[!] JACK: server sent more frames (%d) than input buffer size (%d)\n",
+		   nframes, ctx->input->size));
+    nframes = ctx->input->size;
+  }
 
   int ok = 0;
   for (chn = 0; chn < 2; chn++) {
@@ -65,12 +68,11 @@ process(jack_nframes_t nframes, void *arg)
   return 0;
 }
 
-static const char **ports;
 
 static void
 setup_ports()
 {
-  unsigned int i;
+  int i;
 
   input_ports = xcalloc(2, sizeof(jack_port_t *));
 
@@ -96,8 +98,6 @@ setup_ports()
 void
 create(Context_t *ctx)
 {
-  ctx->input = Input_new(INSIZE);
-
   if ((client = jack_client_open(PACKAGE, JackNullOption, NULL)) == 0)
     xerror("JACK server not running ?\n");
 
@@ -114,6 +114,10 @@ create(Context_t *ctx)
 
   setup_ports();
 
+  jack_nframes_t insize = jack_get_buffer_size(client);
+  printf("[i] JACK: setting input size to %d\n", insize);
+  ctx->input = Input_new(insize);
+
   if (jack_activate(client))
     xerror("JACK: cannot activate client\n");
 
