@@ -26,7 +26,7 @@ u_long options = BE_NONE;
 
 #define USE_THREAD
 
-static char *file = NULL;
+static const char *file = NULL;
 static SF_INFO	sfi;
 static SNDFILE *sf = NULL;
 
@@ -44,10 +44,11 @@ static void
 open_file()
 {
   /* ouvrir le fichier avec sndfile */
-  sf = sf_open((const char *)file, SFM_READ, &sfi);
+  sf = sf_open(file, SFM_READ, &sfi);
 
-  if (NULL == sf)
+  if (NULL == sf) {
     xerror("sndfile: '%s': %s\n", file, sf_strerror(sf));
+  }
 
   /* initialiser le compteur de frames a lire */
   frames = sfi.frames;
@@ -61,9 +62,9 @@ create(Context_t *ctx)
 
   file = getenv("LEBINIOU_SNDFILE");
 
-  if (NULL == file)
+  if (NULL == file) {
     xerror("sndfile: no LEBINIOU_SNDFILE environment variable specified !\n");
-  else {
+  } else {
     VERBOSE(printf("[i] Reading file '%s'\n", file));
   }
 
@@ -75,6 +76,7 @@ create(Context_t *ctx)
 
   /* creer une Input */
   bufsize = (u_short)((double)sfi.samplerate / ctx->max_fps);
+
   /* printf("[i] Input buffer size = %u\n", bufsize); */
   ctx->input = Input_new(bufsize);
 }
@@ -132,9 +134,8 @@ run(Context_t *ctx)
   /* si lecture finie: on recommence ou on exit */
   if (frames < 1) {
     if (loop) {
-#ifdef DEBUG
-      printf("[i] sndfile: restarting stream '%s'\n", file);
-#endif
+      VERBOSE(printf("[i] sndfile: restarting stream '%s'\n", file));
+
       /* rewind */
       if (-1 == sf_seek(sf, 0, SEEK_SET))
 	xerror("sf_seek\n");
@@ -145,4 +146,3 @@ run(Context_t *ctx)
     }
   }
 }
-
