@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -53,7 +53,10 @@ static inline float
 Rndq(void)
 {
   u_long  a, b;
-  read(urandfd, (void *)&a, sizeof(u_long));
+  ssize_t res;
+  res = read(urandfd, (void *)&a, sizeof(u_long));
+  if (res == -1)
+    xperror("read");
   b = (~0);
   return (((float)a) / ((float)b));
 }
@@ -77,7 +80,10 @@ static inline u_long
 Randq(void)
 {
   u_long  a;
-  read(urandfd, (void *)&a, sizeof(u_long));
+  ssize_t res;
+  res = read(urandfd, (void *)&a, sizeof(u_long));
+  if (res == -1)
+    xperror("read");
   return a;
 }
 
