@@ -31,7 +31,7 @@ u_long id = 1181600027;
 u_long options = BEQ_COLORMAP;
 char dname[] = "Cirrus 2";
 u_long mode = NONE;
-char desc[] = "Flashy colors, possibly reversed";
+char desc[] = "Neon color";
 
 
 #define NCOLORS 7
