@@ -21,7 +21,7 @@
 
 u_long id = 1089234657;
 u_long options = BEQ_LAST;
-char dname[] = "Cross-recurrence plot";
+char dname[] = "X-Recurrence";
 u_long mode = OVERLAY;
 char desc[] = "Cross-recurrence plot of the input";
 
