@@ -38,10 +38,10 @@ smoke(const u_short x, const u_short y)
 
   map_x = x - (5 + b_rand_int_range(0, 12 * Random / 100)) * Speed / 100;
   map_y = y - (5 + b_rand_int_range(0, 12 * Random / 100)) * Speed / 100;
-  
+
   if (map_y > MAXY || map_y < MINY || map_x > MAXX || map_x < MINX)
     map_x = map_y = 0;
-  
+
   m.map_x = map_x;
   m.map_y = map_y;
 
@@ -81,19 +81,3 @@ run(Context_t *ctx)
 {
   Translation_run(t_smoke, ctx);
 }
-
-
-#ifndef EVT_DAWA
-#if HAVE_SDL_H
-u_char
-on_SDL_Event(Context_t *ctx, const SDL_Event *e)
-{
-  if (key(e, SDLK_n)) {
-    on_switch_on(ctx);
-    return 1;
-  }
-  
-  return 0;
-}
-#endif /* HAVE_SDL_H */
-#endif
