@@ -36,7 +36,7 @@ inc_theta()
 
   if (roll_theta > (2 * M_PI))
     roll_theta -= 2 * M_PI;
-  else if (roll_theta < (-2 * M_PI)) 
+  else if (roll_theta < (-2 * M_PI))
     roll_theta += 2 * M_PI;
 }
 
@@ -48,7 +48,7 @@ on_switch_on(Context_t *ctx)
   if (b_rand_boolean())
     roll_freq = -roll_freq;
 #ifdef DEBUG
-  printf("[i] %s: roll_freq= %f\n", __FILE__, roll_freq);
+    VERBOSE(printf("[i] %s: roll_freq= %f\r\n", __FILE__, roll_freq));
 #endif
 }
 
@@ -70,15 +70,15 @@ run(Context_t *ctx)
     u_short j;
 
     b %= (2 * WIDTH);
-    
-    if (b < 0) 
+
+    if (b < 0)
       b += (2 * WIDTH);
     if (b > MAXX)
       b = 2 * WIDTH - b - 1;
-		
+
     for (j = 0; j < HEIGHT; j++)
       set_pixel_nc(dst, i, j, get_pixel_nc(src, b, j));
   }
-  
+
   inc_theta();
 }
