@@ -22,7 +22,7 @@
 #include "particles.h"
 
 u_long id = 1194552390;
-u_long options = BE_SFX3D|BEQ_3D|BEQ_PARTICLES| BEQ_TEST|BEQ_NORANDOM;
+u_long options = BE_SFX3D|BEQ_PARTICLES|BEQ_NORANDOM;
 u_long mode = OVERLAY;
 char desc[] = "Fountain effect";
 
@@ -74,7 +74,7 @@ static void
 Delay3_init(Context_t *ctx)
 {
   u_short i;
-	
+
   pthread_mutex_lock(&ctx->input->mutex);
 
   /* Map cubique (x y z) */
@@ -99,7 +99,7 @@ create(Context_t *ctx)
     options |= BEQ_DISABLED;
     return;
   }
-  
+
   ps = Particle_System_new(PS_NOLIMIT);
 
   s = Spline_new(SPAN_SIZE, ctx->input->size - 2);
