@@ -242,19 +242,3 @@ run(Context_t *ctx)
 
   /* printf ("%li active drops\n", active_drops); */
 }
-
-#ifndef EVT_DAWA
-#ifdef HAVE_SDL_H
-u_char
-on_SDL_Event(Context_t *ctx, const SDL_Event *e)
-{
-  if (key(e, SDLK_m)) {
-    drops_mode = !drops_mode;
-    printf("[d] drops mode switched to %s\n", (drops_mode ? "normal" : "special"));
-    return 1;
-  }
-
-  return 0;
-}
-#endif /* HAVE_SDL_H */
-#endif
