@@ -18,13 +18,13 @@
  */
 
 #include "context.h"
-#include "pictures.h"
+#include "images.h"
 
 
 u_long id = 1090876849;
-u_long options = BE_GFX|BEQ_PICTURE;
+u_long options = BE_GFX|BEQ_IMAGE;
 u_long mode = NORMAL;
-char desc[] = "Random picture squares";
+char desc[] = "Random image squares";
 
 
 #define SQUARE_SIZE 40
@@ -34,7 +34,7 @@ char desc[] = "Random picture squares";
 void
 create(Context_t *ctx)
 {
-  if (pictures == NULL)
+  if ((images == NULL) || !images->size)
     options |= BEQ_DISABLED;
 }
 
@@ -43,7 +43,7 @@ void
 run(Context_t *ctx)
 {
   int s;
-  
+
   Buffer8_t *dst = passive_buffer(ctx);
 
   Buffer8_copy(active_buffer(ctx), dst);
@@ -53,11 +53,11 @@ run(Context_t *ctx)
 
     u_short sx = b_rand_int_range(0, MAXX-SQUARE_SIZE);
     u_short sy = b_rand_int_range(0, MAXY-SQUARE_SIZE);
-    
+
     for (j = 0; j < SQUARE_SIZE; j++)
       for (i = 0; i < SQUARE_SIZE; i++)
 	set_pixel_nc(dst,
 		     sx+i, sy+j,
-		     get_pixel_nc(ctx->pf->cur->buff, sx+i, sy+j));
+		     get_pixel_nc(ctx->imgf->cur->buff, sx+i, sy+j));
   }
 }
