@@ -26,19 +26,12 @@ u_long mode = OVERLAY;
 char desc[] = "Pulsing spiral";
 
 
-#ifdef OPTIONS
-u_short nb_conf_opts = 3;
-PluginConf conf[3] = { {"opt1", {(float)1.0} } , { "opt2", {(float)2.0}  }, { "opt3", {(float)2.0}  } };
-#endif
-
-
 void
 create(Context_t *ctx)
-{ 
+{
   if (ctx->input == NULL)
     options |= BEQ_DISABLED;
-  /* printf("BLA :: %s %f\n",conf[0].name,conf[0].value.f ); */
-} 
+}
 
 
 void
@@ -48,24 +41,18 @@ run(Context_t *ctx)
   int i, j;
   float x, y, /*z,*/ theta, phi, r, d , x1 , x2 , x3 = 5;
   Buffer8_t *dst = passive_buffer(ctx);
-	
-  /*
-   * printf("BLA :: %s %f\n",conf[0].name,conf[0].value.f );
-   * printf("BLA :: %s %f\n",conf[1].name,conf[1].value.f );
-   * printf("BLA :: %s %f\n",conf[2].name,conf[2].value.f );
-   */
 
   if (ctx->input == NULL)
     return;
 
   Buffer8_clear(dst);
-	
+
   x1 = Input_get_volume(ctx->input) * WIDTH; /* Nb de pts par droite */
   x2 = 0.3 + ctx->input->data[A_MONO][((int)x1 % ctx->input->size)];
-	
+
   for (i = 0; i < WIDTH; i++) {
     theta = i / 20.0;         /* Rotation angle */
-		
+
     r = expf(theta*x2);        /* Distance from axis  */
     d = 0.33 * r;		  /* Radius relative to r (involute/evolute) */
     /* For ornament, add a periodic function to d */
@@ -73,7 +60,7 @@ run(Context_t *ctx)
       phi = 2.0 * M_PI *j / x3;
       x = d * cosf(phi) *cosf(theta);
       y = d * cosf(phi) *sinf(theta);
-      x += (r * cosf(theta)) + HWIDTH; 
+      x += (r * cosf(theta)) + HWIDTH;
       y += (r * sinf(theta)) + HHEIGHT;
       set_pixel(dst, x, y,  c);
       c++;
