@@ -31,20 +31,6 @@ u_long mode = OVERLAY;
 char desc[] = "Rotors effect";
 
 
-#if !defined(HAVE_CEXP)
-/* FreeBSD doesn't know about cexp (complex.h) */
-inline complex
-cexp(complex c)
-{
-  complex c2;
-
-  __real__ c2 = exp(creal(c)) * cos(cimag(c));
-  __imag__ c2 = exp(creal(c)) * sin(cimag(c));
-
-  return c2;
-}
-#endif /* !defined(HAVE_CEXP) */
-
 #define MAX_ROTORS 16
 
 typedef struct Rotor {
