@@ -21,7 +21,7 @@
 
 u_long id = 1088107667;
 u_long options = BEQ_LAST;
-char dname[] = "Recurrence plot";
+char dname[] = "Recurrence";
 u_long mode = OVERLAY;
 char desc[] = "Recurrence plot of the input";
 
