@@ -75,7 +75,7 @@ change_params()
 static void
 init(Context_t *ctx)
 {
-  int i;
+  uint32_t i;
   Transform_t t;
 
   /* BOF keep gcc happy about uninitialized variables */
