@@ -34,7 +34,7 @@ static int connect = 1;
 static void
 init()
 {
-  int i;
+  uint32_t i;
   Transform_t t;
 
   memset(&t, 0, sizeof(t));
