@@ -34,24 +34,24 @@ static int connect = 1;
 static void
 init()
 {
-	int i;
-	Transform_t t;
+  uint32_t i;
+  Transform_t t;
 
-	memset(&t, 0, sizeof(t));
+  memset(&t, 0, sizeof(t));
 
-	PL->origin.x = PR->origin.x = 0;
+  PL->origin.x = PR->origin.x = 0;
 
-	PL->origin.y = HHEIGHT/2;
-	PR->origin.y = MAXY-HHEIGHT/2;
+  PL->origin.y = HHEIGHT/2;
+  PR->origin.y = MAXY-HHEIGHT/2;
 
-	t.v_j_factor = HMAXY * 0.85;
-	t.v_i.x = 1.0 / (float)(PL->size - 1) * (float)MAXX;
+  t.v_j_factor = HMAXY * 0.85;
+  t.v_i.x = 1.0 / (float)(PL->size - 1) * (float)MAXX;
 
-	for (i = 0; i < PL->size; i++)
-		PL->trans[i] = PR->trans[i] = t;
+  for (i = 0; i < PL->size; i++)
+    PL->trans[i] = PR->trans[i] = t;
 
-	Porteuse_init_alpha(PL);
-	Porteuse_init_alpha(PR);
+  Porteuse_init_alpha(PL);
+  Porteuse_init_alpha(PR);
 }
 
 
