@@ -26,7 +26,7 @@ u_long id = 1177412508;
 u_long options = BE_SFX2D;
 u_long mode = OVERLAY;
 char desc[] = "Zebulon effect";
-char dname[] = "Zebulon swinging bowls";
+char dname[] = "Zebulon bowls";
 
 
 /*
