@@ -17,17 +17,19 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <SDL/SDL.h>
-#include "ttf.h"
+#include <SDL2/SDL.h>
+#include "biniou.h"
+#include "src/defaults.h"
 
-/* #define NO_MOUSE_CURSOR */
+#define NO_MOUSE_CURSOR
 
 u_long id = 1327695029;
 u_long options = BE_NONE;
 
 
-static SDL_Surface *surface;
+static SDL_Window *window = NULL;
 static Plugin_t *glcube = NULL;
+static SDL_GLContext glcontext;
 
 
 static void
@@ -100,8 +102,11 @@ SDL_get_event(Context_t *ctx)
 	// printf("button down @ %d %d\n",  evt.motion.x, evt.motion.y);
 	set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
 	break;
+      }
+      break;
 
-      case SDL_BUTTON_WHEELUP:
+    case SDL_MOUSEWHEEL:
+      if (evt.wheel.y > 0) { // scroll up
 #ifdef WITH_GL /* TODO switch GL/not-GL */
 	if (ctx->params3d.gl_fov > 1)
 	  ctx->params3d.gl_fov--;
@@ -110,9 +115,7 @@ SDL_get_event(Context_t *ctx)
 	ctx->params3d.scale_factor /= 0.9;
 	/* printf("scale: %d\n", ctx->params3d->scale_factor); */
 #endif
-	break;
-
-      case SDL_BUTTON_WHEELDOWN:
+      } else if (evt.wheel.y < 0) { // scroll down
 #ifdef WITH_GL /* TODO switch GL/not-GL */
 	ctx->params3d.gl_fov++;
 	//printf("FOV: %f\n", ctx->params3d.gl_fov);
@@ -120,23 +123,9 @@ SDL_get_event(Context_t *ctx)
 	if (ctx->params3d.scale_factor > 11)
 	  ctx->params3d.scale_factor *= 0.9;
 #endif
-	break;
-
-      default:
-	break;
       }
       break;
 
-#if 0
-#ifndef FIXED
-    case SDL_VIDEORESIZE:
-      out_width = (evt.resize.w >= 8) ? evt.resize.w : out_width;
-      out_height = (evt.resize.h >= 8) ? evt.resize.h : out_height;
-
-      break;
-#endif
-#endif /* 0 */
-
     default:
       break;
     }
@@ -199,12 +188,11 @@ tex_point(const float x, const float y)
 
 
 void
-test_gl3(Context_t *ctx)
+render(Context_t *ctx)
 {
   Context_make_GL_RGBA_texture(ctx, ACTIVE_BUFFER);
 
-  //  glBindTexture(GL_TEXTURE_2D, ctx->textures[ACTIVE_BUFFER]);
-
+  // TODO: quad texture
   glBegin(GL_TRIANGLE_STRIP);
   tex_point(0, 0);
   tex_point(1, 0);
@@ -214,8 +202,6 @@ test_gl3(Context_t *ctx)
   tex_point(0, 1);
   tex_point(1, 1);
   glEnd();
-
-  //glDeleteTextures(1, &ctx->textures[ACTIVE_BUFFER]);
 }
 
 
@@ -239,52 +225,33 @@ run(Context_t *ctx)
       glcube->run(ctx);
     else {
       reshape(WIDTH, HEIGHT);
-      test_gl3(ctx);
+      render(ctx);
     }
   }
 
-  if (ctx->osd_mode != OSD_NONE) {
-    glMatrixMode(GL_MODELVIEW);
-    glLoadIdentity();
-    osd(ctx);
-    /* TODO merge with SDL code
-    if (ctx->random_mode != BR_NONE)
-      osd_random_mode_elapsed(ctx);
-    */
-  }
+  SDL_GL_SwapWindow(window);
 
   SDL_get_event(ctx);
-  SDL_GL_SwapBuffers();
 }
 
 
 void
 fullscreen(const int fs)
 {
-  int do_it = surface->flags & SDL_FULLSCREEN;
-
-  /* houlala c'est loin l'algebre de bool en C... */
-  do_it = (fs && !do_it) || (!fs && do_it);
-
-  if (do_it) {
-    printf("[S] Toggle full-screen\n");
-    SDL_WM_ToggleFullScreen(surface);
+  if (fs) {
+    printf("[S] Set full-screen\n");
+  } else {
+    printf("[S] Unset full-screen\n");
   }
+  SDL_SetWindowFullscreen(window, fs ? SDL_WINDOW_FULLSCREEN : 0);
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-#ifndef FIXED
-  /*
-  sws_freeContext(sws_context);
-  xfree(bufp);
-  xfree(dstbufp);
-  */
-#endif
-  SDL_FreeSurface(surface);
-  ttf_quit();
+  SDL_GL_DeleteContext(glcontext);
+  SDL_DestroyWindow(window);
   SDL_Quit();
 }
 
@@ -292,20 +259,7 @@ destroy(Context_t *ctx)
 void
 switch_cursor()
 {
-  int on;
-
-  on = SDL_ShowCursor(SDL_QUERY);
-  SDL_ShowCursor(on ? SDL_DISABLE : SDL_ENABLE);
-}
-
-
-static void
-resize_window(int width, int height)
-{
-  glViewport(0, 0, width, height);
-
-  //  glMatrixMode(GL_PROJECTION);
-  //  glLoadIdentity();
+  SDL_ShowCursor(SDL_ShowCursor(SDL_QUERY) ? SDL_DISABLE : SDL_ENABLE);
 }
 
 
@@ -318,16 +272,17 @@ init_GL()
   glEnable(GL_DEPTH_TEST);
   glDepthFunc(GL_LEQUAL);
   glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
-
-  /* Initialize font */
-  ttf_init();
 }
 
 
 void
 create(Context_t *ctx)
 {
+  char *icon_file;
+  SDL_Surface *icon = NULL;
+  Uint32 colorkey;
   char *window_title;
+  const int flags = SDL_WINDOW_OPENGL | SDL_GL_DOUBLEBUFFER;
 
   /* Find default output plugin for OpenGL: GLCube */
   /* FIXME hardcoded */
@@ -338,36 +293,13 @@ create(Context_t *ctx)
       glcube->create(ctx);
   }
 
-  /* Information about the current video settings. */
-  const SDL_VideoInfo* info = NULL;
-
-  /* Color depth in bits of our window. */
-  int bpp = 0;
-
-  /* Flags we will pass into SDL_SetVideoMode. */
-  int flags = 0;
-
   /* First, initialize SDL's video subsystem. */
   if (!SDL_WasInit(SDL_INIT_VIDEO))
     if (SDL_Init(SDL_INIT_VIDEO) < 0) {
       /* Failed, exit. */
-      fprintf(stderr, "Video initialization failed: %s\n",
-	      SDL_GetError());
-      exit(1);
+      xerror("Video initialization failed: %s\n", SDL_GetError());
     }
 
-  /* Let's get some video information. */
-  info = SDL_GetVideoInfo();
-
-  if (NULL == info) {
-    /* This should probably never happen. */
-    fprintf(stderr, "Video query failed: %s\n",
-	    SDL_GetError());
-    exit(1);
-  }
-
-  bpp = info->vfmt->BitsPerPixel;
-
   /*
    * Now, we want to setup our requested
    * window attributes for our OpenGL window.
@@ -390,46 +322,35 @@ create(Context_t *ctx)
   SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, 16);
   SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
 
-  /*
-   * TODO:
-   * Make starting windowed an option, and
-   * handle the resize events properly with
-   * glViewport.
-   */
-  flags = SDL_OPENGL;
-  // flags |= SDL_FULLSCREEN;
-  flags |= SDL_GL_DOUBLEBUFFER;
-  flags |= SDL_HWPALETTE;
-  // flags |= SDL_RESIZABLE;
-
-  if (info->hw_available)
-    flags |= SDL_HWSURFACE;
-  else
-    flags |= SDL_SWSURFACE;
-
-  if (info->blit_hw)
-    flags |= SDL_HWACCEL;
-
-  /*
-   * Set the video mode
-   */
-  surface = SDL_SetVideoMode(WIDTH, HEIGHT, bpp, flags);
-  if (NULL == surface) {
-    fprintf(stderr, "Video mode set failed: %s\n",
-	    SDL_GetError());
-    exit(1);
-  }
-
-  init_GL();
+  /* This makes our buffer swap syncronized with the monitor's vertical refresh */
+  SDL_GL_SetSwapInterval(1);
 
   window_title = g_strdup_printf("Le Biniou OpenGL (%dx%d)", WIDTH, HEIGHT);
-  SDL_WM_SetCaption(window_title, NULL);
+  window = SDL_CreateWindow(window_title,
+			    SDL_WINDOWPOS_CENTERED,
+			    SDL_WINDOWPOS_CENTERED,
+			    WIDTH, HEIGHT, flags);
   g_free(window_title);
 
+  if (NULL == window)
+    xerror("Couldn't set %dx%d video mode: %s\n", WIDTH, HEIGHT, SDL_GetError());
+
+  icon_file = g_strdup_printf("%s/lebiniou.bmp", DEFAULT_DATADIR);
+  icon = SDL_LoadBMP(icon_file);
+  g_free(icon_file);
+  colorkey = SDL_MapRGB(icon->format, 0, 0, 0);
+  SDL_SetColorKey(icon, SDL_TRUE, colorkey);
+  SDL_SetWindowIcon(window, icon);
+  SDL_FreeSurface(icon);
+
+  /* Create an OpenGL context associated with the window. */
+  glcontext = SDL_GL_CreateContext(window);
+
+  init_GL();
+
 #ifdef NO_MOUSE_CURSOR
   SDL_ShowCursor(SDL_DISABLE);
 #endif
-  SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
 
-  resize_window(WIDTH, HEIGHT);
+  glViewport(0, 0, WIDTH, HEIGHT);
 }
