@@ -59,7 +59,7 @@ biniou_new(const char *datadir, const char *pluginsdir,
 
     /* Colormaps */
     buf = g_strdup_printf("%s/colormaps/", datadir);
-    VERBOSE(printf("[+] Loading colormaps\n"));
+    VERBOSE(printf("[+] Loading colormaps... "));
     Colormaps_new(buf);
     g_free(buf);
   } else {
@@ -150,16 +150,6 @@ biniou_end()
   else
     context->running = 0; /* This will stop plugins running as threads */
 
-  if (images != NULL) {
-    VERBOSE(printf("[+] Freeing %d images(s)\n", images->size));
-    Images_delete(images);
-  }
-
-  if (colormaps != NULL) {
-    VERBOSE(printf("[+] Freeing %d colormap(s)\n", colormaps->size));
-    Colormaps_delete(colormaps);
-  }
-
   /* TODO %d schemes as above */
   VERBOSE(printf("[+] Freeing schemes\n"));
   Schemes_delete();
@@ -171,6 +161,16 @@ biniou_end()
   /* TODO %d plugins as above */
   VERBOSE(printf("[+] Freeing plugins\n"));
   Plugins_delete(plugins);
+
+  if (images != NULL) {
+    VERBOSE(printf("[+] Freeing %d images(s)\n", images->size));
+    Images_delete(images);
+  }
+
+  if (colormaps != NULL) {
+    VERBOSE(printf("[+] Freeing %d colormap(s)\n", colormaps->size));
+    Colormaps_delete(colormaps);
+  }
 }
 
 
@@ -273,13 +273,6 @@ biniou_set_random_mode(const enum RandomMode r)
 }
 
 
-void
-biniou_set_osd_mode(const enum OSDMode m)
-{
-  Context_set_osd_mode(context, m);
-}
-
-
 void
 biniou_go(const u_long nb_frames, const u_char exit)
 {
