@@ -44,7 +44,6 @@ usage()
 	 "\t-m, --maxfps <fps>\tSet maximum framerate\n"
 	 "\t-o, --output <plugin>\tSet output plugin\n"
 	 "\t-r, --random <mode>\tSet auto-random mode\n"
-	 "\t-s, --screen <mode>\tSet On Screen Display mode\n"
 	 "\t-v, --version\t\tDisplay the version and exit\n"
 	 "\t-q, --quiet\t\tSuppress messages\n"
 #ifndef FIXED
@@ -64,16 +63,21 @@ usage()
 	 "\tInput plugins: %s [default: %s]\n"
 	 "\tOutput plugins: %s [default: %s]\n"
 	 "\n"
+#ifdef MANLINK
 	 "Manual: file://%s\n"
-	 "\n",
-	 PACKAGE_NAME,
+	 "\n"
+#endif
+	 , PACKAGE_NAME,
 #ifdef WITH_WEBCAM
 	 webcams, DEFAULT_VIDEO_DEVICE,
 #endif
 	 PACKAGE_STRING,
 	 INPUT_PLUGINS, DEFAULT_INPUT_PLUGIN,
-	 OUTPUT_PLUGINS, DEFAULT_OUTPUT_PLUGIN,
-	 MANLINK);
+	 OUTPUT_PLUGINS, DEFAULT_OUTPUT_PLUGIN
+#ifdef MANLINK
+	 , MANLINK
+#endif
+	 );
 
   /* TODO print default values for all options */
   exit(0);
@@ -100,7 +104,6 @@ getargs(int argc, char **argv)
 		  {"maxfps", required_argument, NULL, 'm'},
 		  {"output", required_argument, NULL, 'o'},
 		  {"random", required_argument, NULL, 'r'},
-		  {"screen", required_argument, NULL, 's'},
 		  {"quiet", no_argument, NULL, 'q'},
 #ifndef FIXED
 		  {"width", required_argument, NULL, 'x'},
@@ -120,9 +123,9 @@ getargs(int argc, char **argv)
 
 
   /* Get command line arguments */
-  while ((ch = getopt_long(argc, argv, "b:c:d:D:fhi:m:o:p:qr:s:St:x:y:vW:", long_opt, NULL)) != -1)
+  while ((ch = getopt_long(argc, argv, "b:c:d:D:fhi:m:o:p:qr:St:x:y:vW:z:", long_opt, NULL)) != -1)
 #else
-  while ((ch = getopt(argc, argv, "b:c:d:D:fhi:m:o:p:qr:s:St:x:y:vW:")) != -1)
+  while ((ch = getopt(argc, argv, "b:c:d:D:fhi:m:o:p:qr:St:x:y:vW:z:")) != -1)
 #endif
     switch (ch) {
     case 'b':
@@ -186,15 +189,6 @@ getargs(int argc, char **argv)
       }
       break;
 
-    case 's':
-      osd_mode = (enum OSDMode)xatol(optarg);
-      if (osd_mode > OSD_FULL_BG)
-	xerror("Invalid osd_mode (%d)\n", osd_mode);
-      else {
-	VERBOSE(printf("[c] OSD mode set to %d\n", osd_mode));
-      }
-      break;
-
     case 't':
       if (NULL != themes)
 	xfree(themes);
