@@ -122,7 +122,11 @@ Colormaps_new(const char *directoryname)
     xperror("closedir");
 
   colormaps = xcalloc(1, sizeof(Colormaps_t));
-  VERBOSE(printf("[c] Loaded %d colormaps\n", size));
+  if (libbiniou_verbose) {
+    printf("done.\n");
+    pbar_delete(pb);
+    printf("[c] Loaded %d colormaps\n", size);
+  }
 
   if (size) {
     uint16_t i;
@@ -139,9 +143,6 @@ Colormaps_new(const char *directoryname)
     qsort((void *)colormaps->cmaps, (size_t)colormaps->size,
 	  (size_t)sizeof(Cmap8_t *), &Colormaps_compare);
 
-    if (libbiniou_verbose)
-	pbar_delete(pb);
-
     return;
   }
 
