@@ -60,21 +60,8 @@ extern unsigned short WIDTH, HEIGHT;
 #define DEC(val, maxval) do { if (!val) val = maxval-1; else --val; } while (0)
 #define INC(val, maxval) do { if (++val == maxval) val = 0; } while (0)
 
-/* OSD */
-enum OSDMode { OSD_NONE=0, OSD_MINI, OSD_FULL, OSD_FULL_BG };
-
-/* Default font to use, if not set by LEBINIOU_FONT environment variable */
-#define OSD_FONT         "/usr/share/fonts/truetype/freefont/FreeMono.ttf"
-/* Default font size, min and max */
-#define OSD_PTSIZE      20
-#define OSD_PTSIZE_MIN  10
-#define OSD_PTSIZE_MAX  40
-#define OSD_BUFFLEN     512
-
 #define SAVEDIR ".lebiniou/sequences"
 
-#define PB_WIDTH 10 /* progress bars width */
-
 #define MAX_BANKS 12
 
 #define ZMAX 6.0
