@@ -76,8 +76,10 @@ Context_open_webcam(Context_t *ctx)
 	try++;
 	goto retry;
       }
-    } else
+    } else {
       xfree(cams[i]);
+      webcams--;
+    }
   }
 }
 #endif
@@ -151,7 +153,6 @@ Context_new()
   ctx->timer = b_timer_new();
   ctx->fps_timer = b_timer_new();
 
-  ctx->osd_mode = OSD_NONE;
   ctx->display_colormap = 0;
 
   ctx->outputs = NULL;
@@ -472,13 +473,6 @@ Context_set_random_mode(Context_t *ctx, const enum RandomMode r)
 }
 
 
-void
-Context_set_osd_mode(Context_t *ctx, const enum OSDMode m)
-{
-  ctx->osd_mode = m;
-}
-
-
 float
 Context_fps(const Context_t *ctx)
 {
