@@ -53,8 +53,8 @@ enum RandomMode { BR_NONE=0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH } RandomMode_e;
 #define CAM_SAVE 32
 
 typedef struct BKey_s {
-  u_short val;
-  u_short mod;
+  uint32_t val;
+  uint16_t mod;
 } BKey_t;
 
 typedef struct Context_s {
@@ -110,7 +110,6 @@ typedef struct Context_s {
   int      fps[NFPS];
   BTimer_t  *fps_timer;
 
-  enum OSDMode   osd_mode;
   u_char   fullscreen:1;
   u_char   display_colormap:1;
   u_char   take_screenshot:1;
@@ -166,7 +165,6 @@ void Context_randomize(Context_t *);
 
 void Context_set_max_fps(Context_t *, const u_short);
 void Context_set_random_mode(Context_t *, const enum RandomMode);
-void Context_set_osd_mode(Context_t *, const enum OSDMode);
 
 void Context_insert_plugin(Context_t *, Plugin_t *);
 void Context_remove_plugin(Context_t *, Plugin_t *);
