@@ -157,7 +157,7 @@ Context_event(Context_t *ctx, const Event_t *e)
       return 1;
 
     case BA_COLORMAPS:
-      if (colormaps->size > 1) {
+      if ((colormaps != NULL) && (colormaps->size > 1)) {
 	ctx->sm->cur->auto_colormaps = 1-ctx->sm->cur->auto_colormaps;
         Sequence_changed(ctx->sm->cur);
         Context_update_auto(ctx);
@@ -269,10 +269,6 @@ Context_event(Context_t *ctx, const Event_t *e)
 
   case BC_NEXT:
     switch (e->arg0) {
-    case BA_OSD:
-      ctx->osd_mode = (enum OSDMode)((ctx->osd_mode+1) % 4);
-      return 1;
-
     case BA_BOUNDARY:
       ctx->params3d.draw_boundary = (ctx->params3d.draw_boundary+1) % 4;
       return 1;
@@ -317,7 +313,11 @@ Context_event(Context_t *ctx, const Event_t *e)
 
 #ifdef WITH_WEBCAM
     case BA_WEBCAM:
-      ctx->cam = (ctx->cam+1) % webcams;
+      if (webcams) {
+	ctx->cam = (ctx->cam+1) % webcams;
+      } else {
+	printf("[i] No webcams in use\n");
+      }
       return 1;
 #endif
 
@@ -425,9 +425,13 @@ Context_event(Context_t *ctx, const Event_t *e)
 #ifdef WITH_WEBCAM
   case BC_SET:
     if (e->arg0 == BA_WEBCAM) {
-      pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
-      Buffer8_copy(ctx->cam_save[ctx->cam][0], ctx->cam_ref[ctx->cam]);
-      pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
+      if (webcams) {
+	pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+	Buffer8_copy(ctx->cam_save[ctx->cam][0], ctx->cam_ref[ctx->cam]);
+	pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
+      } else {
+	printf("[i] No webcams in use\n");
+      }
       return 1;
     } else {
       return 0;
