@@ -49,9 +49,9 @@ Input_rfftw_create_plan(Input_t *input)
 
 
 Input_t *
-Input_new(const u_short size)
+Input_new(const uint32_t size)
 {
-  int c;
+  uint32_t c;
 #ifdef THREAD_PLAN
   pthread_t fftw_thread;
 #endif
@@ -128,7 +128,7 @@ Input_rfftw_create_plan_threaded(void *huhu)
 static int
 Input_seek_max_spectrum(Input_t *input, int c)
 {
-  int i;
+  uint32_t i;
   u_short new_max = 0;
 
   /* Input_reset_max_spectrum(input); */
@@ -150,7 +150,8 @@ Input_do_fft(Input_t *input)
 {
   /* const int N = input->size; */
   /* const int even = (N % 2 == 0); */
-  int c, k;
+  int c;
+  uint32_t k;
 
 #ifdef THREAD_PLAN
   if (input->plan_fft != NULL)
@@ -216,7 +217,7 @@ Input_set(Input_t *input, u_char mode)
    * A_MONO   => copy A_MONO to A_LEFT and A_RIGHT
    * A_STEREO => compute A_MONO as the average of A_LEFT and A_RIGHT
    */
-  int i, j;
+  uint32_t i, j;
 
   pthread_mutex_lock(&input->mutex);
 
@@ -327,7 +328,7 @@ Input_random_u_char(Input_t *input)
 inline float
 Input_get_volume(Input_t *input)
 {
-  u_short i;
+  uint32_t i;
   float volume = 0;
 
   pthread_mutex_lock(&input->mutex);
