@@ -36,11 +36,13 @@ typedef struct Input_s {
   fftw_plan plan_fft[3];
   
   /* input buffer size */
-  u_short size;
+  uint32_t size;
+
   /* to get Mytho Random Numbers(c)(r)(tm) */
-  u_short roulette;
+  uint32_t roulette;
+
   /* you can also mute the input  */
-  u_char  mute;
+  u_char   mute;
 
   /* Write raw input data here then call Input_set(...) */
   /* the input data, [-1..1] */
@@ -53,7 +55,7 @@ typedef struct Input_s {
   double *data_u[3];
 
   /* spectrum info */
-  u_short spectrum_size;
+  uint32_t spectrum_size;
 
   /* used to compute FFT */
   double *out[3];
@@ -70,7 +72,7 @@ typedef struct Input_s {
 } Input_t;
 
 
-Input_t *Input_new(const u_short);
+Input_t *Input_new(const uint32_t);
 
 void Input_delete(Input_t *);
 void Input_set(Input_t *, u_char);
