@@ -70,7 +70,7 @@ process(GKeyFile *kf)
 #ifndef FIXED
   gint kf_width, kf_height;
 #endif
-  gint kf_fps, kf_osd, kf_rnd;
+  gint kf_fps, kf_rnd;
 #ifdef WITH_WEBCAM
   gchar whflip = FALSE, wvflip = FALSE;
   gint kf_webcams;
@@ -150,20 +150,6 @@ process(GKeyFile *kf)
     error = NULL;
   }
 
-  kf_osd = g_key_file_get_integer(kf, ENGINE, "OSD", &error);
-  if (NULL == error) {
-    if ((kf_osd >= OSD_NONE) && (kf_osd <= OSD_FULL_BG))
-      if ((gint)osd_mode != kf_osd) {
-	osd_mode = kf_osd;
-#ifdef DEBUG
-	printf("[k] Setting OSD to %d\n", kf_osd);
-#endif
-      }
-  } else {
-    g_error_free(error);
-    error = NULL;
-  }
-
   kf_rnd = g_key_file_get_integer(kf, ENGINE, "RandomMode", &error);
   if (NULL == error) {
     if ((kf_rnd >= BR_NONE) && (kf_rnd <= BR_BOTH))
