@@ -20,12 +20,12 @@
 #ifndef __BINIOU_EVENTS_H
 #define __BINIOU_EVENTS_H
 
-#include <SDL/SDL.h>
+#include <SDL2/SDL.h>
 #include "biniou.h"
 
 
 static inline int
-BKEY(const BKey_t *k, const SDLKey v)
+BKEY(const BKey_t *k, const uint32_t v)
 {
   if (k->mod == KMOD_NONE)
     return (k->val == v);
@@ -37,27 +37,27 @@ BKEY(const BKey_t *k, const SDLKey v)
 
 
 static inline int
-BSHIFT(const BKey_t *k, const SDLKey v)
+BSHIFT(const BKey_t *k, const uint32_t v)
 {
   return ((k->val == v) && (k->mod & KMOD_SHIFT));
 }
 
 
 static inline int
-BCTRL(const BKey_t *k, const SDLKey v)
+BCTRL(const BKey_t *k, const uint32_t v)
 {
   return ((k->val == v) && (k->mod & KMOD_CTRL));
 }
 
 
 static inline int
-BALT(const BKey_t *k, const SDLKey v)
+BALT(const BKey_t *k, const uint32_t v)
 {
   return ((k->val == v) && (k->mod & KMOD_ALT));
 }
 
 static inline int
-BCTRLSHIFT(const BKey_t *k, const SDLKey v)
+BCTRLSHIFT(const BKey_t *k, const uint32_t v)
 {
   return ((k->val == v) && (k->mod & KMOD_CTRL) && (k->mod & KMOD_SHIFT));
 }
