@@ -33,7 +33,6 @@ long max_fps = 60;
 u_short width = DEFAULT_WIDTH;
 u_short height = DEFAULT_HEIGHT;
 enum RandomMode random_mode = BR_SCHEMES;
-enum OSDMode osd_mode = OSD_NONE;
 char *pid_file = NULL;
 char *themes = NULL;
 #ifdef WITH_WEBCAM
@@ -178,7 +177,6 @@ main(int argc, char **argv)
 
   biniou_set_max_fps(max_fps);
   biniou_set_random_mode(random_mode);
-  biniou_set_osd_mode(osd_mode);
 
   /* Load input */
   if (NULL != input_plugin) {
