@@ -31,9 +31,9 @@ Transform_init(Transform_t *t)
 
 
 Porteuse_t *
-Porteuse_new(u_short size, u_char channel)
+Porteuse_new(uint32_t size, u_char channel)
 {
-  int i;
+  uint32_t i;
   Porteuse_t *p = xcalloc(1, sizeof(Porteuse_t));
 
   p->size = size;
@@ -58,7 +58,7 @@ Porteuse_delete(Porteuse_t *p)
 void
 Porteuse_init_alpha(Porteuse_t *p)
 {
-  int i;
+  uint32_t i;
   Point2d_t p0;
 
   p0 = p->origin;
@@ -84,7 +84,7 @@ Porteuse_init_alpha(Porteuse_t *p)
 void
 Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
 {
-  int i = 0;
+  uint32_t i = 0;
   Point2d_t origin = p->origin, last;
   Transform_t *t = &p->trans[i];
   Point2d_t sigval;
