@@ -25,24 +25,24 @@
 /* Generic oscillo-style drawing tools */
 
 typedef struct Transform_s {
-	Point2d_t v_before;
-	Point2d_t v_i;
-	Point2d_t v_after;
-	u_short   v_j_factor;
-	float     cos_alpha;
-	float     sin_alpha;
+  Point2d_t v_before;
+  Point2d_t v_i;
+  Point2d_t v_after;
+  u_short   v_j_factor;
+  float     cos_alpha;
+  float     sin_alpha;
 } Transform_t;
 
 void Transform_init(Transform_t *);
 
 typedef struct Porteuse_s {
-	u_short     size;
-	Point2d_t   origin;
-	Transform_t *trans;
-	u_char      channel;
+  uint32_t    size;
+  Point2d_t   origin;
+  Transform_t *trans;
+  u_char      channel;
 } Porteuse_t;
 
-Porteuse_t *Porteuse_new(u_short, u_char);
+Porteuse_t *Porteuse_new(uint32_t, u_char);
 void Porteuse_delete(Porteuse_t *);
 
 void Porteuse_init_alpha(Porteuse_t *);
