@@ -42,10 +42,12 @@ pbar_delete(PBar_t *pb)
 void
 pbar_step(PBar_t *pb)
 {
-  static char progress[] = "/-\\|";
+  if (pb != NULL) {
+    static char progress[] = "/-\\|";
 
-  printf("%c%c", progress[(int)pb->step++], 8);
-  fflush(stdout);
-  if (pb->step == 4)
-    pb->step = 0;
+    printf("%c%c", progress[(int)pb->step++], 8);
+    fflush(stdout);
+    if (pb->step == 4)
+      pb->step = 0;
+  }
 }
