@@ -41,6 +41,6 @@ void Schemes_new(const char *);
 void Schemes_new_default();
 void Schemes_delete();
 
-void Schemes_random();
+void Schemes_random(Context_t *);
 
 #endif /* __BINIOU_SCHEMES_H */
