@@ -33,12 +33,12 @@ typedef struct Sequence_s {
   Plugin_t *lens;           /* lens, NULL if none */
 
   /* TODO ShufflerMode_e */
-  u_char   auto_colormaps;    /* Auto-change colormaps at random interval */
-  uint32_t cmap_id;           /* colormap to use, -1 if default */
+  u_char   auto_colormaps;  /* Auto-change colormaps at random interval */
+  uint32_t cmap_id;         /* colormap to use, -1 if default */
 
   /* TODO ShufflerMode_e */
-  u_char   auto_pictures;     /* Auto-change pictures  at random interval */
-  uint32_t  picture_id;        /* picture to use, 0 if default */
+  u_char   auto_images;     /* Auto-change images  at random interval */
+  uint32_t image_id;        /* image to use, 0 if default */
 } Sequence_t;
 
 
