@@ -19,7 +19,7 @@
 
 #include "globals.h"
 #include "xmlutils.h"
-#include "pictures.h"
+#include "images.h"
 #include "colormaps.h"
 
 
@@ -33,7 +33,7 @@ Sequence_load(const char *file)
 {
   Sequence_t *s = NULL;
   xmlDocPtr doc = NULL; /* XmlTree */
-  xmlNodePtr sequence_node = NULL, plugins_node = NULL;
+  xmlNodePtr sequence_node = NULL, sequence_node_save = NULL, plugins_node = NULL;
   int res;
   long tmp;
   char *dot = NULL;
@@ -50,7 +50,7 @@ Sequence_load(const char *file)
     printf("[!] Not a sequence filename: '%s'\n", file);
 #endif
     return NULL;
-  }    
+  }
 
 #ifdef DEBUG
   printf("[i] Loading sequence from file '%s'\n", file);
@@ -70,7 +70,7 @@ Sequence_load(const char *file)
   g_free(blah);
   if (doc == NULL)
     xerror("xmlParseFile error\n");
-  
+
   sequence_node = xmlDocGetRootElement(doc);
   if (sequence_node == NULL) {
     VERBOSE(printf("[!] Sequence %s: xmlDocGetRootElement error\n", file));
@@ -110,50 +110,57 @@ Sequence_load(const char *file)
     char *cmap = xmlGetMandatoryString(doc, "colormap", sequence_node);
     s->cmap_id = Colormaps_find(cmap);
     xfree(cmap);
-  } else 
+  } else
     s->cmap_id = Colormaps_random_id();
-    
-  /* then, get <auto_pictures> */
-  sequence_node = sequence_node->next;
-  sequence_node = xmlFindElement("auto_pictures", sequence_node);
+
+  int legacy = 0;
+  /* then, get  <auto_images> or (legacy) <auto_pictures> */
+  sequence_node_save = sequence_node = sequence_node->next;
+  sequence_node = xmlFindElement("auto_images", sequence_node);
   if (sequence_node == NULL) {
-    VERBOSE(printf("[!] Sequence %s: no <auto_pictures> found\n", file));
-    goto error;
+    sequence_node = sequence_node_save;
+    sequence_node = xmlFindElement("auto_pictures", sequence_node);
+    if (sequence_node == NULL) {
+      VERBOSE(printf("[!] Sequence %s: no <auto_images> or <auto_pictures> found\n", file));
+      goto error;
+    } else {
+      legacy = 1;
+    }
   }
   res = xmlGetOptionalLong(doc, sequence_node, &tmp);
   if (res == -1)
-    s->auto_pictures = 0;
+    s->auto_images = 0;
   else
-    s->auto_pictures = (u_char)tmp;
-  assert((s->auto_pictures == 0) || (s->auto_pictures == 1));
+    s->auto_images = (u_char)tmp;
+  assert((s->auto_images == 0) || (s->auto_images == 1));
 #ifdef DEBUG
-  printf("[i] Random pictures: %s\n", (s->auto_pictures ? "on" : "off"));
+  printf("[i] Random images: %s\n", (s->auto_images ? "on" : "off"));
 #endif
 
-  if (!s->auto_pictures) {
-    /* not auto*, get picture name */
-    char *picture = xmlGetMandatoryString(doc, "picture", sequence_node);
+  if (!s->auto_images) {
+    /* not auto*, get image name */
+    char *image = xmlGetMandatoryString(doc, legacy ? "picture" : "image", sequence_node);
 #ifdef DEBUG
-    printf("[i] Need picture: '%s'\n", picture);
+    printf("[i] Need image: '%s'\n", image);
 #endif
-    if (pictures == NULL) {
-      VERBOSE(printf("[!] No pictures are loaded, won't find '%s'\n", picture));
-      xfree(picture);
+    if (images == NULL) {
+      VERBOSE(printf("[!] No images are loaded, won't find '%s'\n", image));
+      xfree(image);
       goto error;
     } else {
-      s->picture_id = Pictures_find(picture);
-      if (s->picture_id == 0) {
-	VERBOSE(printf("[!] Picture '%s' not found, using default\n", picture));
+      s->image_id = Images_find(image);
+      if (s->image_id == 0) {
+	VERBOSE(printf("[!] Image '%s' not found, using default\n", image));
       }
-      xfree(picture);
+      xfree(image);
     }
   } else {
-    if (pictures == NULL) {
+    if (images == NULL) {
       s->broken = 1;
-      s->picture_id = -1;
-      s->auto_pictures = 0;
+      s->image_id = -1;
+      s->auto_images = 0;
     } else
-      s->picture_id = Pictures_random_id(); //pictures);
+      s->image_id = Images_random_id();
   }
 
   /* now, get plugins */
@@ -190,7 +197,7 @@ Sequence_load(const char *file)
       enum LayerMode mode;
 
       layer = Layer_new(p);
-      
+
       youhou = xmlGetProp(plugins_node, (const xmlChar *)"mode");
       if (youhou != NULL) {
 	mode = LayerMode_from_string((const char *)youhou);
@@ -198,9 +205,9 @@ Sequence_load(const char *file)
       } else
 	mode = NORMAL;
       layer->mode = mode;
-      
+
       s->layers = g_list_append(s->layers, (gpointer)layer);
-      
+
       if (lens)
 	s->lens = (Plugin_t *)p;
     }
@@ -210,7 +217,7 @@ Sequence_load(const char *file)
 
   /* Check sequence length */
   assert(Sequence_size(s) <= MAX_SEQ_LEN);
-  
+
   /* Clean up */
   xmlFreeDoc(doc);
   xmlCleanupParser(); /* FIXME is this ok ? */
