@@ -33,7 +33,9 @@ xmlFindElement(const char *element, xmlNodePtr start)
   }
 
   if (start == NULL) {
+#ifdef DEBUG
     printf("[!] xmlFindElement(%s): not found\n", element);
+#endif
     return NULL;
   }
 
